@@ -1,30 +1,37 @@
 #' @export
 #' @rdname gggeo_scale
-#' @param obj An object of class \code{ggplot}, \code{gtable}, or \code{geo_scale} (as produced by this function).
+#' @param obj An object of class `ggplot`, `gtable`, or `geo_scale` (as produced by this function).
 gggeo_scale <- function(obj, ...) {
+  lifecycle::deprecate_soft("1.0.0", "gggeo_scale()", "coord_geo()")
   UseMethod("gggeo_scale")
 }
 
-#' Add a geologic scale to ggplots
+#' Add a geologic scale below ggplots using *grid*
 #'
-#' This function takes a ggplot object and adds a geologic time scale at the specified side.
+#' @description
+#' `r lifecycle::badge('deprecated')`
 #'
-#' If custom data is provided (with \code{dat}), it should consist of at least 3 columns of data. See \code{data(periods)} for an example.
-#'   The \code{name} column lists the names of each time interval. These will be used as labels if no abbreviations are provided.
-#'   The \code{max_age} column lists the oldest boundary of each time interval.
-#'   The \code{min_age} column lists the youngest boundary of each time interval.
-#'   The \code{abbr} column is optional and lists abbreviations that may be used as labels.
-#'   The \code{color} column is also optional and lists a hex color code (which can be obtained with \code{rgb()}) for each time interval.
+#' This function takes a ggplot object and adds a geologic time scale at the specified side using the grid and gtable packages.
+#'
+#' If custom data is provided (with `dat`), it should consist of at least 3 columns of data. See `data(periods)` for an example.
+#'   The `name` column lists the names of each time interval. These will be used as labels if no abbreviations are provided.
+#'   The `max_age` column lists the oldest boundary of each time interval.
+#'   The `min_age` column lists the youngest boundary of each time interval.
+#'   The `abbr` column is optional and lists abbreviations that may be used as labels.
+#'   The `color` column is also optional and lists a hex color code (which can be obtained with `rgb()`) for each time interval.
+#' @section Life cycle:
+#' This function is soft-deprecated in favor of [coord_geo()] as of **deeptime** version 1.0.0.
+#' It may be removed in the future.
 #' @param lims The limits of the axis of the desired side of the plot. Only required if using a gtable object not created by this function.
 #' @param dat Either A) a string indicating a built-in dataframe with interval data from the ICS ("periods", "epochs", "stages", "eons", or "eras"),
-#'   B) a string indicating a timescale from macrostrat (see list here: \url{https://macrostrat.org/api/defs/timescales?all}),
+#'   B) a string indicating a timescale from macrostrat (see list here: <https://macrostrat.org/api/defs/timescales?all>),
 #'   or C) a custom dataframe of time interval boundaries (see Details).
-#' @param fill The fill color of the boxes. The default is to use the colors included in \code{dat}.
-#'   If a custom dataset is provided with \code{dat} without color and without fill, a greyscale will be used.
+#' @param fill The fill color of the boxes. The default is to use the colors included in `dat`.
+#'   If a custom dataset is provided with `dat` without color and without fill, a greyscale will be used.
 #'   Custom fill colors can be provided with this option and will be recycled if/as necessary.
 #' @param color The outline color of the interval boxes.
 #' @param alpha The transparency of the fill colors.
-#' @param height The height (or width if \code{pos} is \code{left} or \code{right}) of the scale.
+#' @param height The height (or width if `pos` is `left` or `right`) of the scale.
 #' @param pos Which side to add the scale to (left, right, top, or bottom). First letter may also be used.
 #' @param lab Whether to include labels.
 #' @param rot The amount of counter-clockwise rotation to add to the labels (in degrees).
@@ -34,13 +41,14 @@ gggeo_scale <- function(obj, ...) {
 #' @param lwd Line width.
 #' @param margin The width of the margin around the returned object (can be a vector of length 4).
 #' @param neg Set this to true if your x-axis is using negative values.
-#' @param bord A vector specifying on Which sides of the scale to add borders (same options as \code{pos}).
+#' @param bord A vector specifying on Which sides of the scale to add borders (same options as `pos`).
 #' @param center_end_labels Should labels be centered within the visible range of intervals at the ends of the axis?
 #' @return A geo_scale object. Basically a gtable object but with the axis limits included.
 #' @importFrom gtable gtable_add_grob gtable_add_cols gtable_add_rows gtable_add_padding
 #' @importFrom grid unit
 #' @importFrom ggplot2 ggplot geom_rect geom_segment geom_text annotate aes scale_fill_manual theme_void theme coord_cartesian coord_flip scale_x_reverse
 #' @importFrom methods is
+#' @keywords internal
 #' @export
 #' @aliases gggeo_scale
 #' @rdname gggeo_scale
@@ -115,7 +123,7 @@ gggeo_scale.gtable <- function(obj, lims, dat = "periods", fill = NULL, color =
   if(is(dat, "data.frame")){
     #just use the supplied data
   }else{
-    dat <- getScaleData(dat)
+    dat <- get_scale_data(dat)
   }
   if(neg){
     dat$max_age <- -1 * (dat$max_age)
@@ -312,6 +320,7 @@ gggeo_scale.ggplot <- function(obj, dat = "periods", fill = NULL, color = "black
                      margin = margin, neg = neg, bord = bord, center_end_labels = center_end_labels)
 }
 
+#' @keywords internal
 #' @export
 #' @rdname gggeo_scale
 gggeo_scale.geo_scale <- function(obj, dat = "periods", fill = NULL, color = "black", alpha = 1,
@@ -327,7 +336,8 @@ gggeo_scale.geo_scale <- function(obj, dat = "periods", fill = NULL, color = "bl
 }
 
 #' @param x An object of class geo_scale.
-#' @param ... further arguments passed to \code{\link[grid]{grid.draw}}.
+#' @param ... further arguments passed to [grid::grid.draw()].
+#' @keywords internal
 #' @export
 #' @rdname gggeo_scale
 #' @importFrom grid grid.newpage grid.draw
