@@ -1,7 +1,5 @@
 test_that("coord_geo works", {
-  if(!suppressPackageStartupMessages(require(divDyn, quietly = TRUE))) {
-    skip("divDyn not available for coord_geo")
-  }
+  skip_if_not_installed("divDyn")
   gg <- ggplot(coral_div) +
     geom_line(aes(x = stage_age, y = n)) +
     scale_x_reverse("Age (Ma)") +
@@ -23,9 +21,7 @@ test_that("coord_geo works", {
 })
 
 test_that("stacking scales works", {
-  if(!suppressPackageStartupMessages(require(divDyn, quietly = TRUE))) {
-    skip("divDyn not available for stacking scales")
-  }
+  skip_if_not_installed("divDyn")
   gg <- ggplot(coral_div) +
     geom_line(aes(x = stage_age, y = n)) +
     scale_x_reverse("Age (Ma)") +
@@ -33,42 +29,36 @@ test_that("stacking scales works", {
     coord_geo(dat = list("periods", "eras"), xlim = c(250, 0), ylim = c(0, 1700),
               pos = list("b", "b"), abbrv = list(TRUE, FALSE)) +
     theme_classic()
-  expect_doppelganger("stacked scales", gg)
+  expect_doppelganger_deeptime("stacked scales", gg)
 })
 
 test_that("scales on different sides works", {
   skip_if_offline(host = "macrostrat.org")
-  if(!suppressPackageStartupMessages(require(gsloid, quietly = TRUE))) {
-    skip("gsloid not available for scales on different sides")
-  }
+  skip_if_not_installed("gsloid")
   gg <- ggplot(lisiecki2005) +
     geom_line(aes(x = d18O, y = Time/1000), orientation = "y") +
-    scale_y_reverse("Time (Ma)") +
+    scale_y_reverse("Time (Ma)", sec.axis = sec_axis(~.)) +
     scale_x_reverse() +
     coord_geo(dat = list("Geomagnetic Polarity Chron", "Planktic foraminiferal Primary Biozones"),
               xlim = c(6,2), ylim = c(5.5,0), pos = list("l", "r"), rot = 90, skip = "PL4", size = list(5, 4)) +
     theme_classic()
-  expect_doppelganger("scales on different sides", gg)
+  expect_doppelganger_deeptime("scales on different sides", gg)
 })
 
 test_that("scales on facetted plot works", {
-  if(!suppressPackageStartupMessages(require(divDyn, quietly = TRUE))) {
-    skip("divDyn not available for facetted plot")
-  }
+  skip_if_not_installed("divDyn")
   gg <- ggplot(coral_div_diet) +
     geom_line(aes(x = stage_age, y = n)) +
     scale_x_reverse("Age (Ma)") +
     ylab("Coral Genera") +
     coord_geo(xlim = c(250, 0)) +
     theme_classic()
-  expect_doppelganger("scale on only one facet", gg + facet_wrap(~diet, nrow = 3))
-  expect_doppelganger("scale on all facets", gg + facet_wrap(~diet, nrow = 3, scales = "free_x"))
+  expect_doppelganger_deeptime("scale on only one facet", gg + facet_wrap(~diet, nrow = 3))
+  expect_doppelganger_deeptime("scale on all facets", gg + facet_wrap(~diet, nrow = 3, scales = "free_x"))
 })
 
 test_that("auto-discrete scale works", {
-  if(!suppressPackageStartupMessages(require(divDyn, quietly = TRUE))) {
-    skip("divDyn not available for auto-discrete scale")
-  }
+  skip_if_not_installed("divDyn")
   gg <- ggplot(coral_div_dis) +
     geom_col(aes(x = period, y = n, fill = diet)) +
     scale_x_discrete("Period", limits = unique(coral_div_dis$period), labels = NULL, expand = expansion(add = .5)) +
@@ -78,13 +68,11 @@ test_that("auto-discrete scale works", {
     coord_geo(expand = TRUE, skip = NULL, abbrv = FALSE) +
     theme_classic() +
     theme(axis.ticks.length.x = unit(0, "lines"))
-  expect_doppelganger("scale on discrete axis", gg)
+  expect_doppelganger_deeptime("scale on discrete axis", gg)
 })
 
 test_that("custom discrete scale works", {
-  if(!suppressPackageStartupMessages(require(divDyn, quietly = TRUE))) {
-    skip("divDyn not available for custom discrete scale")
-  }
+  skip_if_not_installed("divDyn")
   eras_custom <- data.frame(name = c("Mesozoic", "Cenozoic"), max_age = c(0.5, 3.5), min_age = c(3.5, 6.5), color = c("#67C5CA", "#F2F91D"))
 
   gg <- ggplot(coral_div_dis) +
@@ -96,13 +84,11 @@ test_that("custom discrete scale works", {
     coord_geo(dat = list("periods", eras_custom), pos = c("b", "b"), expand = TRUE, skip = NULL, abbrv = FALSE, dat_is_discrete = list(FALSE, TRUE)) +
     theme_classic() +
     theme(axis.ticks.length.x = unit(0, "lines"))
-  expect_doppelganger("custom discrete scale", gg)
+  expect_doppelganger_deeptime("custom discrete scale", gg)
 })
 
 test_that("geom_fit_text() works", {
-  if(!suppressPackageStartupMessages(require(divDyn, quietly = TRUE))) {
-    skip("divDyn not available for geom_fit_text")
-  }
+  skip_if_not_installed("divDyn")
   gg <- ggplot(coral_div) +
     geom_line(aes(x = stage_age, y = n)) +
     scale_x_reverse("Age (Ma)") +
@@ -110,30 +96,22 @@ test_that("geom_fit_text() works", {
     coord_geo(dat = "periods", xlim = c(250, 0), ylim = c(0, 1700),
               abbrv = FALSE, size = "auto", fittext_args = list(size = 20)) +
     theme_classic()
-  expect_doppelganger("geom_fit_text()", gg)
+  expect_doppelganger_deeptime("geom_fit_text()", gg)
 })
 
 test_that("ggtree scale works", {
-  if(!suppressPackageStartupMessages(require(ggtree, quietly = TRUE))) {
-    skip("ggtree not available for coord_geo")
-  }
-  if(!suppressPackageStartupMessages(require(phytools, quietly = TRUE))) {
-    skip("phytools not available for coord_geo")
-  }
+  skip_if_not_installed("ggtree")
+  skip_if_not_installed("phytools")
   gg <- ggtree(mammal.tree) +
     coord_geo(xlim = c(-75,0), ylim = c(-2,Ntip(mammal.tree)), neg = TRUE, abbrv = FALSE) +
     scale_x_continuous(breaks=seq(-80,0,20), labels=abs(seq(-80,0,20))) +
     theme_tree2()
-  expect_doppelganger("scale on ggtree", revts(gg))
+  expect_doppelganger_deeptime("scale on ggtree", revts(gg))
 })
 
 test_that("ggtree scale works with only fossil taxa", {
-  if(!suppressPackageStartupMessages(require(ggtree, quietly = TRUE))) {
-    skip("ggtree not available for fossil tree")
-  }
-  if(!suppressPackageStartupMessages(require(paleotree, quietly = TRUE))) {
-    skip("paleotree not available for fossil tree")
-  }
+  skip_if_not_installed("ggtree")
+  skip_if_not_installed("paleotree")
   gg <- ggtree(ceratopsianTreeRaia, position = position_nudge(x = -ceratopsianTreeRaia$root.time)) +
     coord_geo(xlim = c(-163.5,-66), ylim = c(-2,Ntip(ceratopsianTreeRaia)), pos = list("bottom", "bottom"),
               skip = c("Paleocene", "Middle Jurassic"), dat = list("epochs", "periods"), abbrv = FALSE,
@@ -141,5 +119,5 @@ test_that("ggtree scale works with only fossil taxa", {
     scale_x_continuous(breaks = -rev(epochs$max_age), labels = rev(epochs$max_age)) +
     theme_tree2() +
     theme(plot.margin = margin(7,11,7,11))
-  expect_doppelganger("scale on fossil ggtree", gg)
+  expect_doppelganger_deeptime("scale on fossil ggtree", gg)
 })
