@@ -1,4 +1,15 @@
+test_that("gggeo_scale() is deprecated", {
+  p <- ggplot(coral_div) +
+    geom_line(aes(x = stage_age, y = n)) +
+    scale_x_reverse("Age (Ma)") +
+    ylab("Coral Genera") +
+    coord_cartesian(xlim = c(250, 0), ylim = c(0, 1700), expand = FALSE) +
+    theme_classic()
+  lifecycle::expect_deprecated(gggeo_scale(p))
+})
+
 test_that("gggeo_scale() works", {
+  withr::local_options(lifecycle_verbosity = "quiet")
   skip_if_not_installed("divDyn")
   p <- ggplot(coral_div) +
     geom_line(aes(x = stage_age, y = n)) +
